/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Sessions.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.mavenplugin.examples.directoryexploded;

import java.io.Serializable;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;

/**
 * Entity bean for table Sessions.
 * @author Julien Blais
 */
@Entity
@Table(name = "SESSIONS")
@NamedQueries({
@NamedQuery(name = "Sessions.findAll", query = "SELECT s FROM Sessions s"),
@NamedQuery(name = "Sessions.findByUsername", query = "SELECT s FROM Sessions s WHERE s.username = :username"),
@NamedQuery(name = "Sessions.findByPasswd", query = "SELECT s FROM Sessions s WHERE s.passwd = :passwd")})
public class Sessions implements Serializable {
    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = 23789478748784790L;

    /**
     * User name of the session.
     * Primary key of the table.
     */
    @Id
    @Basic(optional = false)
    @Column(name = "USERNAME")
    private String username;

    /**
     * User Password.
     */
    @Basic(optional = false)
    @Column(name = "PASSWD")
    private String passwd;

    /**
     * Empty constructor.
     */
    public Sessions() {
    }

    /**
     * Creates a new session instance.
     * @param username the user name
     * @param passwd the user password
     */
    public Sessions(final String username, final String passwd) {
        this.username = username;
        this.passwd = passwd;
    }

    /**
     * Gets the user name.
     * @return the user name
     */
    public String getUsername() {
        return username;
    }

    /**
     * Set the user name of the session.
     * @param username the new user name of this session
     */
    public void setUsername(final String username) {
        this.username = username;
    }

    /**
     * Gets the user password of this session.
     * @return the password
     */
    public String getPasswd() {
        return passwd;
    }

    /**
     * Sets the user password.
     * @param passwd the new user password
     */
    public void setPasswd(final String passwd) {
        this.passwd = passwd;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        if (username != null) {
            hash += username.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        if (!(object instanceof Sessions)) {
            return false;
        }
        Sessions other = (Sessions) object;
        if ((this.username == null && other.username != null)
                || (this.username != null && !this.username.equals(other.username))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "Sessions[username=" + username + "]";
    }

}
